@@ -1,10 +1,12 @@
-#!python 
-import pycuda.gpuarray as gpuarray
-import pycuda.driver as drv
-import pycuda.autoinit
+#!python
+from __future__ import annotations
+
 import numpy as np
 
+import pycuda.gpuarray as gpuarray
 from pycuda.compiler import SourceModule
+
+
 func_mod = SourceModule("""
 template <class T>
 __device__ T incr(T x) {
@@ -23,7 +25,7 @@ extern "C" {
 }
 """, no_extern_c=1)
 
-func = func_mod.get_function('func')
+func = func_mod.get_function("func")
 
 N = 5
 x = np.asarray(np.random.rand(N), np.float32)
@@ -31,6 +33,5 @@ x_orig = x.copy()
 x_gpu = gpuarray.to_gpu(x)
 
 func(x_gpu.gpudata, np.uint32(N), block=(N, 1, 1))
-print('x:       ', x)
-print('incr(x): ', x_gpu.get())
-
+print("x:       ", x)
+print("incr(x): ", x_gpu.get())
