@@ -1,10 +1,11 @@
-import pycuda.driver as drv
-import pycuda.tools
-import pycuda.autoinit
+from __future__ import annotations
+
 import numpy
-import numpy.linalg as la
+
+import pycuda.driver as drv
 from pycuda.compiler import SourceModule
 
+
 mod = SourceModule("""
 __global__ void multiply_them(float *dest, float *a, float *b)
 {
@@ -21,6 +22,6 @@ b = numpy.random.randn(400).astype(numpy.float32)
 dest = numpy.zeros_like(a)
 multiply_them(
         drv.Out(dest), drv.In(a), drv.In(b),
-        block=(400,1,1))
+        block=(400, 1, 1))
 
 print(dest-a*b)
