@@ -1,6 +1,8 @@
-from __future__ import absolute_import
+from __future__ import annotations
+
 import pycuda._driver as _drv
 
+
 if not _drv.have_gl_ext():
     raise ImportError("PyCUDA was compiled without GL extension support")
 
